@@ -6,10 +6,15 @@
 #'
 #' @rdname Calculus
 #'
-#' @param formula A formula. The right side specifies the variable(s) with which to 
+#' @param formula A formula. The right side of a formula specifies 
+#'   the variable(s) with which to 
 #'   carry out the integration or differentiation.  On the left side should be 
 #'   an expression or a function that returns a numerical vector 
-#'   of the same length as its argument.  The expression can contain unbound variables.
+#'   of the same length as its argument.  
+#'   The expression can contain unbound variables.  Functions
+#'   will be differentiated as if the formula {f(x) ~ x} were specified
+#'   but with \code{x} replaced by the first argument of \code{f}.
+#'   
 #'
 #' @param \dots Default values to be given to unbound variables in the expression \code{expr}.  
 #' See examples.#'  Note that in creating anti-derivative functions, 
@@ -60,10 +65,25 @@
 #' f <- makeFun(x^2~x)
 #' D(f(cos(z))~z) #will look in user functions also
 #' @export
- 
+
 D <- function(formula, ..., .hstep=NULL,add.h.control=FALSE){
-  tryCatch( return( stats::D(formula, ...) ), error=function(e) {}  )
+    UseMethod("D")
+}
+
+#' @rdname Calculus
+#' @export
+D.default <- function(formula, ..., .hstep=NULL,add.h.control=FALSE){
+  tryCatch( return( stats::D(formula, ...) ), error=function(e) {}  ) 
+  stop( paste("First argument should be a formula that explicitly identifies the",
+              "variable with respect to which the derivative is to be taken. ",
+              "Example:  D(sin(x) ~ x).", sep ="\n  " ) )
+}
   
+#' @rdname Calculus
+#' @export
+D.formula <- function(formula, ..., .hstep=NULL,add.h.control=FALSE){
+  tryCatch( return( stats::D(formula, ...) ), error=function(e) {}  )
+
   formulaEnv = environment(formula) # where was the formula made?
   #Try to construct a symbolic derivative
   res = try(symbolicD(formula, ...), silent=TRUE)
