@@ -33,6 +33,20 @@ setGeneric(
 		   }
 		   )
 
+#' @rdname makeFun
+#' @aliases makeFun,function-method
+#' @export
+
+setMethod(
+  'makeFun',
+  'function',
+  function( object, ..., strict.declaration =TRUE, use.environment=TRUE, 
+            suppress.warnings=FALSE) {
+    object
+  }
+)    
+
+
 #' @rdname makeFun
 #' @aliases makeFun,formula-method
 #' @param strict.declaration  if \code{TRUE} (the default), an error is thrown if 
@@ -55,6 +69,7 @@ setGeneric(
 #' 
 #' @export
 
+
 setMethod(
   'makeFun',
   'formula',
