@@ -49,9 +49,14 @@ logical2factor.data.frame  <- function( x, ... ) {
 #' When programming, it is best to use an explicit \code{data} argument
 #' -- ideally supplying a data frame that contains the variables mentioned
 #' @param format a character string describing the desired format of the results.
-#'        One of \code{'default'}, \code{'count'}, \code{'proportion'}, or \code{'percent'}.
+#'        One of \code{'default'}, \code{'count'}, \code{'proportion'}, \code{'percent'}, 
+#'        \code{'data.frame'}, \code{'sparse'}, or \code{'default'}.
 #'        In case of \code{'default'}, counts are used unless there is a condition, in
-#'        which case proportions are used instead.
+#'        which case proportions are used instead.  Note that prior to version 0.9.3, 
+#'        \code{'default'} was the default, now it is \code{'count'}.
+#'        \code{'data.frame'} converts the table to a data frame with one row per cell;
+#'        \code{'sparse'} additionally removes any rows with 0 counts.
+#'        
 #' @param subset an expression evaluating to a logical vector used to select a subset of \code{data}
 #' @param quiet a logical indicating whether messages about order in which marginal distributions
 #'        are calculated should be surpressed.  See \code{\link{addmargins}}.
@@ -63,6 +68,8 @@ logical2factor.data.frame  <- function( x, ... ) {
 #' The \pkg{dplyr} package also exports a \code{\link[dplyr]{tally}} function.  If \code{x} inherits 
 #' from class \code{"tbl"}, then \pkg{dplyr}'s \code{tally} is called.  This makes it
 #' easier to have the two package coexist.
+#' @note The curent implementation when \code{format = "sparse"} first creates the full data frame
+#' and then removes the unneeded rows.  So the savings is in terms of space, not time.
 #' @examples
 #' if (require(mosaicData)) {
 #' tally( ~ substance, data=HELPrct)
@@ -103,7 +110,7 @@ tally.tbl <- function(x, wt, sort=FALSE, ..., envir=parent.frame()) {
 #' @export
 
 tally.default <- function(x, data=parent.frame(), 
-                      format=c('default','count','proportion','percent'), 
+                      format=c('count', 'proportion', 'percent', 'data.frame', 'sparse', 'default'), 
                       margins=FALSE,
                       quiet=TRUE,
                       subset, 
@@ -152,12 +159,15 @@ tally.default <- function(x, data=parent.frame(),
 	res <- switch(format,
 		   'count' = 
 				res,
+       'data.frame' = as.data.frame(res),
+       'sparse' = {res <- as.data.frame(res); res <- res[res$Freq > 0,]},
 		   'proportion' = 
 		   		prop.table( res, margin = ncol(evalF$right) + columns(evalF$condition) ),
 		   'percent' = 
 		   		100 * prop.table( res, margin = ncol(evalF$right) + columns(evalF$condition) )
 		   )
-	if (margins) {  # add margins for the non-condition dimensions of the table
+	if (margins & ! format %in% c("data.frame", "sparse")) {  
+    # add margins for the non-condition dimensions of the table
     if ( !is.null(evalF$right) & ncol(evalF$right) > 0 )
 		  res <- addmargins(res, 1:ncol(evalF$right), FUN=list(Total=sum), quiet=quiet )
 	}
@@ -205,8 +215,15 @@ rows <- function(x, default=c()) {
 #' @param long.names a logical indicating whether long names should be 
 #'         when there is a conditioning variable
 #' @param sep a character used to separate portions of long names
+#' @param useNA an indication of how NA's should be handled.  By default, they are
+#'   ignored.
 #' @param format one of \code{proportion}, \code{percent}, or \code{count},
 #'        possibly abbrevaited
+#' @param quiet a logical indicating whether messages should be supressed.
+#'
+#' @note For 0-1 data, level is set to 1 by default since that a standard 
+#' coding scheme for success and failure.
+#' 
 #' @examples
 #' if (require(mosaicData)) {
 #' prop( ~sex, data=HELPrct)
@@ -217,21 +234,35 @@ rows <- function(x, default=c()) {
 #' }
 #' @export
 
-prop <- function(x, data=parent.frame(), ..., level=NULL, long.names=TRUE, sep=".", format="proportion") {
-  T <- mosaic::tally(x, data=data, ..., format=format)
+prop <- function(x, data=parent.frame(), useNA = "no", ..., level=NULL, 
+                 long.names=TRUE, sep=".", 
+                 format="proportion", quiet=FALSE) {
+  T <- mosaic::tally(x, data=data, useNA = useNA, ..., format=format)
   if (length(dim(T)) < 1) stop("Insufficient dimensions.")
+  lnames <- dimnames(T)[[1]]
   if (is.null(level)) {
-	  level <- dimnames(T)[[1]][1]
-  	  if (level == 'FALSE') level <- 'TRUE'
+	  level <- lnames[1]
+  	if (level == 'FALSE') level <- 'TRUE'
+    if (level == 0 && lnames[2] ==1 && length(lnames) == 2) {
+      level <- 1
+    }
   }
+  if (! level %in% lnames) stop(
+    paste("I don't see any such level.  Only", paste(lnames, collapse=", "))
+    )
+  if (! quiet) message(paste0( "    target level: ", level, 
+                              ";  other levels: ", 
+                              paste(setdiff(lnames,level), collapse=", "), "\n" ) )
   if ( length(dim(T)) == 2) {
-    result <- T[level,]
+    idx <- match(level, lnames)
+    result <- T[idx,]
     if (long.names)
       names(result) <- paste(level, names(result), sep=sep)
     return(result)
   }
   if ( length(dim(T)) == 1) {
-    result <- T[level]
+    idx <- match(level, names(T))
+    result <- T[idx]
     return(result)
   }
   stop(paste('Too many dimensions (', length(dim(T)), ")",sep=""))
